##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def install(self):
    path_list = []

    # XXX use_passwd and passwd should be deprecated, they have confusing names.
    if not self.optionIsTrue('use_passwd', False):
      masterauth = "# masterauth <master-password>"
    else:
      masterauth = "masterauth %s" % self.options['passwd']

    if self.options.get('masterauth'):
      masterauth = "masterauth %s" % self.options['masterauth']
    else:
      masterauth = "# masterauth <master-password>"

    if self.options.get('requirepass'):
      requirepass = "requirepass %s" % self.options['requirepass']
    else:
      requirepass = "# requirepass foobared"

    if self.options.get('ipv6'):
      bind6 = "bind6 %s" % self.options['ipv6']
    else:
      bind6 = "# bind6 <address>"

    if self.options.get('ipv4'):
      bind = "bind %s" % self.options['ipv4']
    else:
      bind = "# bind <address>"

    if self.options.get('port6'):
      port6 = "port6 %s" % self.options['port6']
    else:
      port6 = "# port6 6379"

    if self.options.get('port'):
      port = "port %s" % self.options['port']
    else:
      port = "# port 6379"

    config_file = self.options['config_file'].strip()
    configuration = {
            'pid_file': self.options['pid_file'],
            'bind6': bind6,
            'bind': bind,
            'port6': port6,
            'port': port,
            'server_dir': self.options['server_dir'],
            'log_file': self.options['log_file'],
            'masterauth': masterauth,
            'requirepass': requirepass
        }

    config = self.createFile(config_file,
      self.substituteTemplate(self.getTemplateFilename('redis.conf.in'),
      configuration))
    path_list.append(config)

    redis = self.createPythonScript(
      self.options['wrapper'],
      'slapos.recipe.librecipe.execute.execute',
      [self.options['server_bin'], config_file]
    )
    path_list.append(redis)

    promise_script = self.options.get('promise_wrapper', '').strip()
    if promise_script:
      promise = self.createPythonScript(
        promise_script,
        '%s.promise.main' % __name__,
        {
          'host': self.options['ipv6'],
          'port': self.options['port6'],
          'requirepass_file': self.options.get('promise_requirepass_file')
        }
      )
      path_list.append(promise)

    return path_list

